# © 2022 Le Filament (<https://www.le-filament.com>)
# © 2022 Confédération Générale des Scop (<https://www.les-scop.coop>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).


from odoo.addons.base_rest import restapi
from odoo.addons.component.core import Component


class CgScopGendocUserServices(Component):
    _inherit = ["base.rest.service", "cgscop_gendoc.utils"]
    _name = "cgscopgendoc.user.services"
    _usage = "user"
    _collection = "cgscopgendoc.services.coll"
    _description = """
        Gendoc File API Services
        Services developed with the new api provided by base_rest
    """

    @restapi.method(
        [(["/<int:id>/get", "/<int:id>"], "GET")],
        auth="user",
    )
    def get(self, _id):
        """
        Get user's information
        """

        return self._get(_id)

    # The following method are 'private' and should be never never NEVER call
    # from the controller.

    def _get(self, userId):
        """
        Search for user
        """
        user = self.env["res.users"].browse(userId)

        rows = []
        if not user:
            return {"count": 0, "rows": rows}
        else:
            rows.append(self._to_json(user))
            return {"count": 1, "rows": rows}

    def _to_json(self, user):
        """
        Generate output json
        :param partner: An instance of user
        """
        res = {
            "id": self._getinteger(user.id),
            "login": self._getstring(user.login),
        }

        res["ur"] = self._getnested(user.ur_id)
        res["partner"] = self._getpartner(user.partner_id)

        return res

    def _getpartner(self, partner):
        res = {}
        if partner:
            res.update(
                {
                    "id": self._getinteger(partner.id),
                    "name": self._getstring(partner.name),
                    "title": self._getnested(partner.title),
                    "lastname": self._getstring(partner.lastname),
                    "firstname": self._getstring(partner.firstname),
                    "mobile": self._getstring(partner.mobile),
                    "phone": self._getstring(partner.phone),
                    "image": partner.image_128.decode("utf-8")
                    if partner.image_128
                    else None,
                }
            )
        else:
            res.update({"id": 0, "name": ""})
        return res
